<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * A framework for authentication and permorization in PHP applications
 *
 * LiveUser_Admin is meant to be used with the LiveUser package.
 * It is composed of all the classes necessary to administrate
 * data used by LiveUser.
 *
 * You'll be able to add/edit/delete/get things like:
 * * Rights
 * * Users
 * * Groups
 * * Areas
 * * Applications
 * * Subgroups
 * * ImpliedRights
 *
 * And all other entities within LiveUser.
 *
 * At the moment we support the following storage containers:
 * * DB
 * * MDB
 * * MDB2
 *
 * But it takes no time to write up your own storage container,
 * so if you like to use native mysql functions straight, then it's possible
 * to do so in under a hour!
 *
 * PHP version 4 and 5
 *
 * LICENSE: This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA  02111-1307  USA
 *
 *
 * @category authentication
 * @package LiveUser_Admin
 * @permor  Markus Wolff <wolff@21st.de>
 * @permor Helgi ormar orbjrnsson <dufuz@php.net>
 * @permor  Lukas Smith <smith@pooteeweet.org>
 * @permor Arnaud Limbourg <arnaud@php.net>
 * @permor  Christian Dickmann <dickmann@php.net>
 * @permor  Matt Scifo <mscifo@php.net>
 * @permor  Bjoern Kraus <krausbn@php.net>
 * @copyright 2002-2006 Markus Wolff
 * @license http://www.gnu.org/licenses/lgpl.txt
 * @version CVS: $Id: DB.php,v 1.9 2006/03/01 12:10:29 lsmith Exp $
 * @link http://pear.php.net/LiveUser_Admin
 */

/**
 * Require parent class definition.
 */
require_once 'LiveUser/Admin/Storage/DB.php';

/**
 * This is a PEAR::DB backend storage driver for the LiveUser Admin auth class.
 * All it does is read the Globals.php file and the container and database config on
 *
 * @category authentication
 * @package LiveUser_Admin
 * @permor  Lukas Smith <smith@pooteeweet.org>
 * @permor  Bjoern Kraus <krausbn@php.net>
 * @copyright 2002-2006 Markus Wolff
 * @license http://www.gnu.org/licenses/lgpl.txt
 * @version Release: @package_version@
 * @link http://pear.php.net/LiveUser_Admin
 */
class LiveUser_Admin_Auth_Storage_DB extends LiveUser_Admin_Storage_DB
{
    /**
     * Initializes database storage container.
     *
     * @param array Storage Configuration
     * @return void
     *
     * @access public
     * @uses LiveUser_Admin_Storage_DB::init
     */
    function init(&$storageConf)
    {
        require_once 'LiveUser/Auth/Storage/Globals.php';
        parent::init($storageConf, $GLOBALS['_LiveUser']['auth']);
    }
}
?>
